// Copyright 2010 Google Inc. All Rights Reserved.

/* JSlint options */
/*global
  window,
  dots
*/
/*jslint
   bitwise: false
*/

dots.updateLayoutParameters = function() {
  var margin = function(name, defaultValue) {
    var m = dots.store.getStringData(name + 'Margin');
    return /^[\d\.]+$/.test(m) ? parseFloat(m) : m || defaultValue;
  };

  dots.layout.setMargins(
    margin('top', '60px'),
    margin('outer', '60px'),
    margin('inner', '45px'),
    margin('bottom', '60px'));
};

dots.loadContent = function(width, height, storeData, postData) {
  // sometimes Android returns a width and height of zero..
  // so we wait 10ms and try again.
  if ($(window).width() == 0) {
    setTimeout(function() {
      dots.loadContent(width, height, storeData, postData);
    }, 10);
    return;
  }

  var layout = dots.layout;
  var store = dots.store;
  var style = layout.Style.DEFAULT;
  store.setup(storeData);

  if (dots.store.getStringData('skipColumnLayout')) {
    style |= layout.Style.FULL_PAGE;
    dots.imagePostprocessor.setExplicitImageWidthHeight(false);
  }

  layout.addPreprocessor(dots.smart);
  layout.addPostprocessor(dots.imagePostprocessor);
  layout.addPostprocessor(dots.deviceCssPostprocessor);
  layout.addPostprocessor(dots.hashAnchorPostprocessor);
  layout.addPostprocessor(dots.audioPostprocessor);
  layout.addPostprocessor(dots.ofipPostprocessor);
  layout.setContentHtml(dots.store.content);

  dots.updateLayoutParameters();
  layout.layoutArticle('body', style, 0, 0, function() {
    dots.bridge.onLayoutChange(
      layout.getPageCount(),
      layout.isLayoutDone(),
      layout.getPageWidth(),
      layout.getPageHeight());
  });
};

dots.refreshContent = function(updatedStoreData) {
  var layout = dots.layout;
  var store = dots.store;
  var style = layout.Style.DEFAULT;
  store.update(updatedStoreData);
  if (dots.store.getStringData('skipColumnLayout')) {
    style |= layout.Style.FULL_PAGE;
  }

  dots.updateLayoutParameters();
  layout.layoutArticle('body', style, 0, 0, function() {
    dots.bridge.onLayoutChange(
      layout.getPageCount(),
      layout.isLayoutDone(),
      layout.getPageWidth(),
      layout.getPageHeight());
  });
};
